[Libreoffice-commits] .: hwpfilter/CppunitTest_hwpfilter_test_hwpfilter.mk i18npool/CppunitTest_i18npool_test_breakiterator.mk lotuswordpro/CppunitTest_lotuswordpro_test_lotuswordpro.mk Makefile.in sc/CppunitTest_sc_test_filters.mk sc/CppunitTest_sc_ucalc.mk sd/CppunitTest_sd_uimpress.mk smoketestoo_native/losmoketest.py solenv/gbuild starmath/CppunitTest_starmath_qa_cppunit.mk svtools/CppunitTest_svtools_filters_test.mk sw/CppunitTest_sw_swdoc_test.mk sw/CppunitTest_sw_test_filters.mk test/source writerfilter/CppunitTest_writerfilter_rtftok.mk

Stephan Bergmann sbergmann at kemper.freedesktop.org
Fri Sep 16 01:41:03 PDT 2011


 Makefile.in                                                |    2 -
 hwpfilter/CppunitTest_hwpfilter_test_hwpfilter.mk          |    2 -
 i18npool/CppunitTest_i18npool_test_breakiterator.mk        |    3 --
 lotuswordpro/CppunitTest_lotuswordpro_test_lotuswordpro.mk |    1 
 sc/CppunitTest_sc_test_filters.mk                          |    2 -
 sc/CppunitTest_sc_ucalc.mk                                 |    1 
 sd/CppunitTest_sd_uimpress.mk                              |    1 
 smoketestoo_native/losmoketest.py                          |    1 
 solenv/gbuild/JunitTest.mk                                 |    3 --
 starmath/CppunitTest_starmath_qa_cppunit.mk                |    2 -
 svtools/CppunitTest_svtools_filters_test.mk                |    1 
 sw/CppunitTest_sw_swdoc_test.mk                            |    1 
 sw/CppunitTest_sw_test_filters.mk                          |    2 -
 test/source/cpp/officeconnection.cxx                       |   15 +++++++------
 test/source/java/org/openoffice/test/OfficeConnection.java |   11 +--------
 writerfilter/CppunitTest_writerfilter_rtftok.mk            |    2 -
 16 files changed, 12 insertions(+), 38 deletions(-)

New commits:
commit 7d1bb036e1d0c20920703e64132d76e4cce06826
Author: Stephan Bergmann <sbergman at redhat.com>
Date:   Fri Sep 16 10:38:06 2011 +0200

    Simplified setting headless mode for smoke-/subsequenttetss.
    
    Both C++ and Java OfficeConnection code now always pass --headless, so no
    need for SAL_USE_VCLPLUGIN=svp etc. any more.  Only some C++ unit tests that
    link against vcl still need an explicit --headless.

diff --git a/Makefile.in b/Makefile.in
index eba4838..fde29e4 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -36,7 +36,6 @@ distro-pack-install: install
 dev-install:|all
 	@. ./Env.Host.sh && \
 	cd smoketestoo_native && \
-		export SAL_USE_VCLPLUGIN="svp" && \
 		build.pl -P at BUILD_NCPUS@ --all:instsetoo_native -- -P at BUILD_MAX_JOBS@ && \
 		cd @abs_builddir@ && ln -s $$SOLARVER/$$INPATH/installation/opt/ install && \
 		echo "" && \
@@ -94,7 +93,6 @@ Makefile: autogen.lastrun configure.in ooo.lst.in set_soenv.in Makefile.in
 check: Makefile dmake/dmake at EXEEXT_FOR_BUILD@ fetch
 	@. ./Env.Host.sh && \
 	cd smoketestoo_native && \
-	export SAL_USE_VCLPLUGIN="svp" && \
         build.pl -P at BUILD_NCPUS@ --all -- -P at BUILD_MAX_JOBS@
 	@. ./Env.Host.sh && $(MAKE) -f "$$SRC_ROOT"/GNUmakefile.mk -r \
             $(if @VERBOSE@,,-s) --jobs="$(if \
diff --git a/hwpfilter/CppunitTest_hwpfilter_test_hwpfilter.mk b/hwpfilter/CppunitTest_hwpfilter_test_hwpfilter.mk
index 71579c9..bade4c8 100644
--- a/hwpfilter/CppunitTest_hwpfilter_test_hwpfilter.mk
+++ b/hwpfilter/CppunitTest_hwpfilter_test_hwpfilter.mk
@@ -66,8 +66,6 @@ $(eval $(call gb_CppunitTest_add_service_rdbs,hwpfilter_test_hwpfilter,\
 ))
 
 $(eval $(call gb_CppunitTest_set_args,hwpfilter_test_hwpfilter,\
-    --headless \
-    --invisible \
     --protector unoexceptionprotector$(gb_Library_DLLEXT) unoexceptionprotector \
 ))
 
diff --git a/i18npool/CppunitTest_i18npool_test_breakiterator.mk b/i18npool/CppunitTest_i18npool_test_breakiterator.mk
index 9c35bf6..d0dca44 100644
--- a/i18npool/CppunitTest_i18npool_test_breakiterator.mk
+++ b/i18npool/CppunitTest_i18npool_test_breakiterator.mk
@@ -60,8 +60,7 @@ $(eval $(call gb_CppunitTest_add_service_rdbs,i18npool_test_breakiterator,\
 ))
 
 $(eval $(call gb_CppunitTest_set_args,i18npool_test_breakiterator,\
-	--headless \
-	--invisible \
+    --protector unoexceptionprotector$(gb_Library_DLLEXT) unoexceptionprotector \
 ))
 
 $(eval $(call gb_RdbTarget_RdbTarget,i18npool_test_breakiterator))
diff --git a/lotuswordpro/CppunitTest_lotuswordpro_test_lotuswordpro.mk b/lotuswordpro/CppunitTest_lotuswordpro_test_lotuswordpro.mk
index 8fa7f4f..ea178dc 100644
--- a/lotuswordpro/CppunitTest_lotuswordpro_test_lotuswordpro.mk
+++ b/lotuswordpro/CppunitTest_lotuswordpro_test_lotuswordpro.mk
@@ -67,7 +67,6 @@ $(eval $(call gb_CppunitTest_add_service_rdbs,lotuswordpro_test_lotuswordpro,\
 
 $(eval $(call gb_CppunitTest_set_args,lotuswordpro_test_lotuswordpro,\
     --headless \
-    --invisible \
     --protector unoexceptionprotector$(gb_Library_DLLEXT) unoexceptionprotector \
 ))
 
diff --git a/sc/CppunitTest_sc_test_filters.mk b/sc/CppunitTest_sc_test_filters.mk
index d7aa043..cf524d9 100644
--- a/sc/CppunitTest_sc_test_filters.mk
+++ b/sc/CppunitTest_sc_test_filters.mk
@@ -92,8 +92,6 @@ $(eval $(call gb_CppunitTest_add_service_rdbs,sc_filters_test,\
 ))
 
 $(eval $(call gb_CppunitTest_set_args,sc_filters_test,\
-    --headless \
-    --invisible \
     --protector unoexceptionprotector$(gb_Library_DLLEXT) unoexceptionprotector \
     -env:OOO_CONFIG_REGISTRY_DIR=$(call gb_CppunitTarget__make_url,$(OUTDIR)/xml/registry) \
 ))
diff --git a/sc/CppunitTest_sc_ucalc.mk b/sc/CppunitTest_sc_ucalc.mk
index 91fe524..c7a6b2f 100644
--- a/sc/CppunitTest_sc_ucalc.mk
+++ b/sc/CppunitTest_sc_ucalc.mk
@@ -98,7 +98,6 @@ $(eval $(call gb_CppunitTest_add_service_rdbs,sc_ucalc,\
 
 $(eval $(call gb_CppunitTest_set_args,sc_ucalc,\
     --headless \
-    --invisible \
     --protector unoexceptionprotector$(gb_Library_DLLEXT) unoexceptionprotector \
 ))
 
diff --git a/sd/CppunitTest_sd_uimpress.mk b/sd/CppunitTest_sd_uimpress.mk
index 43352bc..6791a53 100644
--- a/sd/CppunitTest_sd_uimpress.mk
+++ b/sd/CppunitTest_sd_uimpress.mk
@@ -92,7 +92,6 @@ $(eval $(call gb_CppunitTest_add_service_rdbs,sd_uimpress,\
 
 $(eval $(call gb_CppunitTest_set_args,sd_uimpress,\
     --headless \
-    --invisible \
     --protector unoexceptionprotector$(gb_Library_DLLEXT) unoexceptionprotector \
 ))
 
diff --git a/smoketestoo_native/losmoketest.py b/smoketestoo_native/losmoketest.py
index 5da7fd7..e18c3f3 100644
--- a/smoketestoo_native/losmoketest.py
+++ b/smoketestoo_native/losmoketest.py
@@ -438,7 +438,6 @@ def verify_smoketest():
     arc = p[2]
 
     if s == "Linux":
-        os.environ['SAL_USE_VCLPLUGIN'] = "svp"
         os.environ['LD_LIBRARY_PATH'] = ""
         os.environ['LD_LIBRARY_PATH'] = ':'.join([os.path.join(root_dir, 'lib'), INSTALL_DIR + '/opt/libreoffice' + build_version + '/ure/lib', os.environ['LD_LIBRARY_PATH']])
         cmd_cppu = [
diff --git a/solenv/gbuild/JunitTest.mk b/solenv/gbuild/JunitTest.mk
index a93576c..083898d 100644
--- a/solenv/gbuild/JunitTest.mk
+++ b/solenv/gbuild/JunitTest.mk
@@ -30,7 +30,6 @@
 # JunitTest class
 
 gb_JunitTest_JAVACOMMAND := $(JAVAINTERPRETER) $(JAVAIFLAGS)
-gb_JunitTest_HEADLESS := $(true)
 
 # in non-product builds, ensure that tools-based assertions do not pop up as message box, but are routed to the shell
 DBGSV_ERROR_OUT := shell
@@ -51,8 +50,6 @@ $(call gb_JunitTest_get_target,%) :
 		mkdir -p $(call gb_JunitTest_get_userdir,$*) && \
         ($(gb_JunitTest_JAVACOMMAND) \
             -cp "$(CLASSPATH)" \
-            $(if $(strip $(gb_JunitTest_HEADLESS)),\
-                -Dorg.openoffice.test.arg.headless=$(gb_JunitTest_HEADLESS)) \
             $(if $(strip $(gb_JunitTest_DEBUGCOMMAND)),\
                 '-Dorg.openoffice.test.arg.debugcommand=$(gb_JunitTest_DEBUGCOMMAND)') \
             $(DEFS) \
diff --git a/starmath/CppunitTest_starmath_qa_cppunit.mk b/starmath/CppunitTest_starmath_qa_cppunit.mk
index 50ff0d9..0e73dcc 100644
--- a/starmath/CppunitTest_starmath_qa_cppunit.mk
+++ b/starmath/CppunitTest_starmath_qa_cppunit.mk
@@ -89,8 +89,6 @@ $(eval $(call gb_CppunitTest_add_service_rdbs,starmath_qa_cppunit,\
 ))
 
 $(eval $(call gb_CppunitTest_set_args,starmath_qa_cppunit,\
-    --headless \
-    --invisible \
     --protector unoexceptionprotector$(gb_Library_DLLEXT) unoexceptionprotector \
 ))
 
diff --git a/svtools/CppunitTest_svtools_filters_test.mk b/svtools/CppunitTest_svtools_filters_test.mk
index b580db6..04a4309 100644
--- a/svtools/CppunitTest_svtools_filters_test.mk
+++ b/svtools/CppunitTest_svtools_filters_test.mk
@@ -63,7 +63,6 @@ $(eval $(call gb_CppunitTest_add_type_rdbs,svtools_filters_test,\
 
 $(eval $(call gb_CppunitTest_set_args,svtools_filters_test,\
     --headless \
-    --invisible \
     --protector unoexceptionprotector$(gb_Library_DLLEXT) unoexceptionprotector \
 ))
 
diff --git a/sw/CppunitTest_sw_swdoc_test.mk b/sw/CppunitTest_sw_swdoc_test.mk
index d2dfb06..0c9c1bc 100644
--- a/sw/CppunitTest_sw_swdoc_test.mk
+++ b/sw/CppunitTest_sw_swdoc_test.mk
@@ -101,7 +101,6 @@ $(call gb_CppunitTest_get_target,sw_swdoc_test) : \
 
 $(eval $(call gb_CppunitTest_set_args,sw_swdoc_test,\
     --headless \
-    --invisible \
     --protector unoexceptionprotector$(gb_Library_DLLEXT) unoexceptionprotector \
 ))
 
diff --git a/sw/CppunitTest_sw_test_filters.mk b/sw/CppunitTest_sw_test_filters.mk
index 7098fcb..1411e7c 100644
--- a/sw/CppunitTest_sw_test_filters.mk
+++ b/sw/CppunitTest_sw_test_filters.mk
@@ -77,8 +77,6 @@ $(eval $(call gb_CppunitTest_add_service_rdbs,sw_filters_test,\
 ))
 
 $(eval $(call gb_CppunitTest_set_args,sw_filters_test,\
-    --headless \
-    --invisible \
     --protector unoexceptionprotector$(gb_Library_DLLEXT) unoexceptionprotector \
 ))
 
diff --git a/test/source/java/org/openoffice/test/OfficeConnection.java b/test/source/java/org/openoffice/test/OfficeConnection.java
index 8cd2967..b05c34b 100644
--- a/test/source/java/org/openoffice/test/OfficeConnection.java
+++ b/test/source/java/org/openoffice/test/OfficeConnection.java
@@ -53,20 +53,13 @@ public final class OfficeConnection {
     public void setUp() throws Exception {
         String sofficeArg = Argument.get("soffice");
         if (sofficeArg.startsWith("path:")) {
-            String headless_flags = "";
-            try {
-                if(Argument.get("headless").length() > 0) {
-                    headless_flags = "--headless";
-                }
-            } catch(Exception e) {}
             description = "pipe,name=oootest" + UUID.randomUUID();
             ProcessBuilder pb = new ProcessBuilder(
                 sofficeArg.substring("path:".length()), "--quickstart=no",
-                "--nofirststartwizard", "--norestore", "--nologo",
+                "--nofirststartwizard", "--norestore", "--nologo", "--headless",
                 "--accept=" + description + ";urp",
                 "-env:UserInstallation=" + Argument.get("user"),
-                "-env:UNO_JAVA_JFW_ENV_JREHOME=true",
-                headless_flags);
+                "-env:UNO_JAVA_JFW_ENV_JREHOME=true");
             String envArg = Argument.get("env");
             if (envArg != null) {
                 Map<String, String> env = pb.environment();
diff --git a/writerfilter/CppunitTest_writerfilter_rtftok.mk b/writerfilter/CppunitTest_writerfilter_rtftok.mk
index e6ad45f..a6077fc 100644
--- a/writerfilter/CppunitTest_writerfilter_rtftok.mk
+++ b/writerfilter/CppunitTest_writerfilter_rtftok.mk
@@ -61,8 +61,6 @@ $(eval $(call gb_CppunitTest_add_service_rdbs,writerfilter_rtftok,\
 ))
 
 $(eval $(call gb_CppunitTest_set_args,writerfilter_rtftok,\
-	--headless \
-	--invisible \
 	--protector unoexceptionprotector$(gb_Library_DLLEXT) unoexceptionprotector \
 ))
 


More information about the Libreoffice-commits mailing list
diff --git a/test/source/cpp/officeconnection.cxx b/test/source/cpp/officeconnection.cxx
index fe3ad5a..a40451e 100644
--- a/test/source/cpp/officeconnection.cxx
+++ b/test/source/cpp/officeconnection.cxx
@@ -74,8 +74,10 @@ void OfficeConnection::setUp() {
         rtl::OUString nofirstArg(
             RTL_CONSTASCII_USTRINGPARAM("--nofirststartwizard"));
         rtl::OUString norestoreArg(RTL_CONSTASCII_USTRINGPARAM("--norestore"));
-        //Disable use of the unix standalone splash screen app for the tests
-        rtl::OUString noSplashArg(RTL_CONSTASCII_USTRINGPARAM("--nologo"));
+        rtl::OUString nologoArg(RTL_CONSTASCII_USTRINGPARAM("--nologo"));
+            // disable use of the unix standalone splash screen app for the
+            // tests (probably not needed in combination with --headless?)
+        rtl::OUString headlessArg(RTL_CONSTASCII_USTRINGPARAM("--headless"));
         rtl::OUString acceptArg(
             rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("--accept=")) + desc +
             rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(";urp")));
@@ -93,8 +95,9 @@ void OfficeConnection::setUp() {
             RTL_CONSTASCII_USTRINGPARAM(
                 "-env:UNO_JAVA_JFW_ENV_CLASSPATH=true"));
         rtl_uString * args[] = {
-            noquickArg.pData, nofirstArg.pData, norestoreArg.pData, noSplashArg.pData,
-            acceptArg.pData, userArg.pData, jreArg.pData, classpathArg.pData };
+            noquickArg.pData, nofirstArg.pData, norestoreArg.pData,
+            nologoArg.pData, headlessArg.pData, acceptArg.pData, userArg.pData,
+            jreArg.pData, classpathArg.pData };
         rtl_uString ** envs = 0;
         rtl::OUString argEnv;
         if (detail::getArgument(
@@ -107,8 +110,8 @@ void OfficeConnection::setUp() {
             osl_executeProcess(
                 toAbsoluteFileUrl(
                     argSoffice.copy(RTL_CONSTASCII_LENGTH("path:"))).pData,
-                args, SAL_N_ELEMENTS( args ), 0, 0, 0, envs,
-                envs == 0 ? 0 : 1, &process_));
+                args, SAL_N_ELEMENTS(args), 0, 0, 0, envs, envs == 0 ? 0 : 1,
+                &process_));
     } else if (argSoffice.matchAsciiL(RTL_CONSTASCII_STRINGPARAM("connect:"))) {
         desc = argSoffice.copy(RTL_CONSTASCII_LENGTH("connect:"));
     } else {